@@ -1,10 +1,7 @@
+use strict; use warnings;
 package Tie::DNS;
-{
-  $Tie::DNS::VERSION = '1.133260';
-}
+$Tie::DNS::VERSION = '1.151560';
 use Carp;
-use strict;
-use warnings;
 use Socket;
 use Net::DNS;
 
@@ -94,7 +91,7 @@ sub TIEHASH {
     my $self = {};
     bless $self, $class;
     
-    $self->{'dns'} = new Net::DNS::Resolver(%{($args->{resolver_args} || {})});
+    $self->{'dns'} = Net::DNS::Resolver->new(%{($args->{resolver_args} || {})});
 
     $self->args($args);
 
@@ -109,12 +106,12 @@ sub STORE {
     my $root_server = $self->get_root_server
         or die 'Dynamic update attempted but no (or bad) domain specified.';
 
-    my $update = new Net::DNS::Update($self->_get_arg('domain'));
+    my $update = Net::DNS::Update->new($self->_get_arg('domain'));
     my $update_string = sprintf('%s. %s %s %s',
         $key, $self->{'ttl'}, $self->{'lookup_type'}, $value);
     $update->push('update', rr_add($update_string));
 
-    my $res = new Net::DNS::Resolver(%{($self->args->{resolver_args} || {})});
+    my $res = Net::DNS::Resolver->new(%{($self->args->{resolver_args} || {})});
     $res->nameservers($root_server);
     my $reply = $res->send($update);
     if (defined $reply) {
@@ -122,11 +119,11 @@ sub STORE {
             return $value;
         } else {
             $self->{'errstring'} = $self->{'dns'}->errorstring;
-            return undef;
+            return 0;
         }
     } else {
         $self->{'errstring'} = $self->{'dns'}->errorstring;
-        return undef;
+        return 0;
     }
 }
 
@@ -153,7 +150,7 @@ sub FIRSTKEY {
     my @full_zone = $self->{'dns'}->axfr($self->{'root_name_server'});
     if (scalar(@full_zone) == 0) {
         $self->{'errstring'} = $self->{'dns'}->errorstring;
-        return undef;
+        return 0;
     }
 
     my @zone;
@@ -169,7 +166,7 @@ sub NEXTKEY {
     my $self = shift;
     my @zone = @{$self->{'zone'}};
     if (scalar(@zone) == 0) {
-        return undef;
+        return 0;
     }
     my $rr = shift(@zone);
     $self->{'zone'} = \@zone;
@@ -255,7 +252,7 @@ sub get_root_server {
 sub _get_arg {
     my $self = shift;
     my $arg_name = shift;
-    return undef unless defined $self->{'args'};
+    return 0 unless defined $self->{'args'};
 
     return $self->{'args'}{$arg_name};
 }
@@ -273,7 +270,7 @@ sub do_reverse_lookup {
         }
     } else {
         $self->{'errstring'} = $self->{'dns'}->errorstring;
-        return undef;
+        return 0;
     }
     if (defined $self->_get_arg('multiple')) {
         return \@retvals;
@@ -396,7 +393,7 @@ See Above.
 Get all of the A records from 'foo.com'.  (Sorry foo.com if
 everyone hits your name server testing this module.  :-)
 
-    tie %dns, 'Tie::DNS', {Domain => 'foo.com'};
+    tie my %dns, 'Tie::DNS', {Domain => 'foo.com'};
 
     while (my ($name, $ip) = each %dns) {
         print "$name = $ip\n";
@@ -427,8 +424,8 @@ Pass the configuration parameter of 'type' to one of the
 Net::DNS supported record types causes all FETCHes to
 get records of that type.
 
-    tie %dns, 'Tie::DNS', {
-        multiple' => 'true',
+    tie my %dns, 'Tie::DNS', {
+        multiple => 'true',
         type => 'SOA'
     };
 
@@ -455,7 +452,7 @@ types and a comprehensive list of all available types.
 
 =head2 Fetching all of the fields associated with a given record type.
 
-    tie %dns, 'Tie::DNS', {type => 'SOA'};
+    tie my %dns, 'Tie::DNS', {type => 'SOA', all_fields => 'true'};
 
     my $dns_ref = $dns{'cnn.com'};
     foreach my $field (keys %{$dns_ref}) {
@@ -472,13 +469,13 @@ is no caching.  The 'cache' argument is passed through to L<Tie::Cache>.
 If L<Tie::Cache> cannot be loaded, caching will be disabled.  Entries
 whose DNS TTL has expired will be re-queried automatically.
 
-    tie %dns, 'Tie::DNS', {cache => 100};
+    tie my %dns, 'Tie::DNS', {cache => 100};
     print "$dns{'cnn.com'}\n";
     print "$dns{'cnn.com'}\n";  ## cached!
 
 =head2 Getting all/different fields associated with a record
 
-    tie %dns, 'Tie::DNS', {all_fields => 'true'};
+    tie my %dns, 'Tie::DNS', {all_fields => 'true'};
     my $dns_ref = $dns{'cnn.com'};
     print $dns_ref->{'ttl'}, "\n";
 
@@ -497,7 +494,7 @@ nameserver is used instead of the default one.
 
 =head2 Changing various arguments to the tie on the fly
 
-    tie %dns, 'Tie::DNS', {type => 'SOA'};
+    tie my %dns, 'Tie::DNS', {type => 'SOA'};
     print "$dns{'cnn.com'}\n";
 
     tied(%dns)->args({type => 'A'});
@@ -511,7 +508,7 @@ changes the default mode to A queries, and displays that.
 Assign into the hash, key DNS name, value IP address, to add a record
 to the zone in the domain argument.  For instance:
 
-    tie %dns, 'Tie::DNS', {
+    tie my %dns, 'Tie::DNS', {
         domain => 'realms.lan',
         multiple => 'true'
     };
@@ -570,7 +567,7 @@ in-addr.arpa zone transfers aren't yet supported.
 Patches, flames, opinions, enhancement ideas are all welcome.
 
 =head1 COPYRIGHT 
-Copyright (c) 2009,2013 Dana M. Diederich. All Rights Reserved.
+Copyright (c) 2009,2013,2015 Dana M. Diederich. All Rights Reserved.
 This module is free software. It may be used, redistributed
 and/or modified under the terms of the Perl Artistic License
   (see http://www.perl.com/perl/misc/Artistic.html)
